try {
    throw 42;
} catch (a__1) {
    function a__1() {}
    console.log(a__1);
}
